@@ -35,8 +35,8 @@
 #include <sys/stat.h>
 
 MainWindow::MainWindow(QWidget *parent, const QString &file)
-    : QDialog(parent)
-    , ui(new Ui::MainWindow)
+    : QDialog(parent),
+      ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
     setConnections();
@@ -52,8 +52,9 @@ MainWindow::~MainWindow()
 
 bool MainWindow::isDockInMenu(const QString &file_name)
 {
-    if (dock_name.isEmpty())
+    if (dock_name.isEmpty()) {
         return false;
+    }
     return getDockName(file_name) == dock_name;
 }
 
@@ -94,17 +95,21 @@ void MainWindow::displayIcon(const QString &app_name, int location)
 
 bool MainWindow::checkDoneEditing()
 {
-    if (!apps.isEmpty())
+    if (!apps.isEmpty()) {
         ui->buttonDelete->setEnabled(true);
+    }
 
     if (ui->buttonSelectApp->text() != tr("Select...") || !ui->lineEditCommand->text().isEmpty()) {
-        if (changed)
+        if (changed) {
             ui->buttonSave->setEnabled(true);
+        }
         ui->buttonAdd->setEnabled(true);
-        if (index != 0)
+        if (index != 0) {
             ui->buttonPrev->setEnabled(true);
-        if (index < apps.size() - 1 && apps.size() > 1)
+        }
+        if (index < apps.size() - 1 && apps.size() > 1) {
             ui->buttonNext->setEnabled(true);
+        }
         return true;
     } else {
         ui->buttonSave->setEnabled(false);
@@ -128,8 +133,9 @@ void MainWindow::setup(const QString &file)
 
     blockComboSignals(true);
 
-    while (ui->icons->layout()->count() > 0)
+    while (ui->icons->layout()->count() > 0) {
         delete ui->icons->layout()->itemAt(0)->widget();
+    }
 
     ui->comboSize->setCurrentIndex(ui->comboSize->findText(QStringLiteral("48x48")));
     file_content.clear();
@@ -161,55 +167,58 @@ void MainWindow::setup(const QString &file)
                      "You can also edit or delete a dock created earlier."));
     mbox->setIcon(QMessageBox::Question);
     mbox->setWindowTitle(tr("Operation mode"));
-    mbox->addButton(tr("&Close"), QMessageBox::NoRole);
-    mbox->addButton(tr("&Move"), QMessageBox::NoRole);
-    mbox->addButton(tr("&Delete"), QMessageBox::NoRole);
-    mbox->addButton(tr("&Edit"), QMessageBox::NoRole);
-    mbox->addButton(tr("C&reate"), QMessageBox::NoRole);
+
+    auto *moveBtn = mbox->addButton(tr("&Move"), QMessageBox::NoRole);
+    auto *deleteBtn = mbox->addButton(tr("&Delete"), QMessageBox::NoRole);
+    auto *editBtn = mbox->addButton(tr("&Edit"), QMessageBox::NoRole);
+    auto *createBtn = mbox->addButton(tr("C&reate"), QMessageBox::NoRole);
+    auto *closeBtn = mbox->addButton(tr("&Close"), QMessageBox::RejectRole);
 
     this->hide();
+    mbox->exec();
 
-    switch (enum {Close, Move, Delete, Edit, New}; mbox->exec()) {
-    case Close:
+    auto *clickedButton = mbox->clickedButton();
+
+    if (clickedButton == closeBtn) {
         QTimer::singleShot(0, QApplication::instance(), &QGuiApplication::quit);
-        break;
-    case Move:
+    } else if (clickedButton == moveBtn) {
         moveDock();
-        break;
-    case Delete:
+    } else if (clickedButton == deleteBtn) {
         this->show();
         deleteDock();
         setup();
-        break;
-    case Edit:
+    } else if (clickedButton == editBtn) {
         this->show();
         editDock();
-        break;
-    case New:
+    } else if (clickedButton == createBtn) {
         newDock();
-        break;
     }
+
     delete mbox;
 }
 
 // Find icon file by name
 QPixmap MainWindow::findIcon(QString icon_name, QSize size)
 {
-    if (icon_name.isEmpty())
+    if (icon_name.isEmpty()) {
         return {};
-    if (QFileInfo::exists("/" + icon_name))
+    }
+    if (QFileInfo::exists("/" + icon_name)) {
         return QIcon(icon_name).pixmap(size);
+    }
 
     QString search_term = icon_name;
     if (!icon_name.endsWith(QLatin1String(".png")) && !icon_name.endsWith(QLatin1String(".svg"))
-        && !icon_name.endsWith(QLatin1String(".xpm")))
+        && !icon_name.endsWith(QLatin1String(".xpm"))) {
         search_term = icon_name + ".*";
+    }
 
     icon_name.remove(QRegularExpression(QStringLiteral(R"(\.png$|\.svg$|\.xpm$")")));
 
     // return the icon from the theme if it exists
-    if (!QIcon::fromTheme(icon_name).isNull())
+    if (!QIcon::fromTheme(icon_name).isNull()) {
         return QIcon::fromTheme(icon_name).pixmap(size);
+    }
 
     // Try to find in most obvious places
     QStringList search_paths {QDir::homePath() + "/.local/share/icons/", "/usr/share/pixmaps/",
@@ -221,8 +230,9 @@ QPixmap MainWindow::findIcon(QString icon_name, QSize size)
         }
         for (const QString ext : {".png", ".svg", ".xpm"}) {
             QString file = path + icon_name + ext;
-            if (QFileInfo::exists(file))
+            if (QFileInfo::exists(file)) {
                 return QIcon(file).pixmap(QSize());
+            }
         }
     }
 
@@ -251,15 +261,17 @@ QString MainWindow::getDockName(const QString &file_name)
         text = re_file.match(text).captured();
         QString name = re_name.match(text).captured().mid(1);
         name.chop(1);
-        if (!name.isEmpty())
+        if (!name.isEmpty()) {
             return name;
+        }
     }
 
     // find dock name in submenus file
     file.setFileName(QDir::homePath() + "/.fluxbox/submenus/appearance");
 
-    if (!file.open(QFile::Text | QFile::ReadOnly))
+    if (!file.open(QFile::Text | QFile::ReadOnly)) {
         return {};
+    }
     QString text = file.readAll();
     file.close();
 
@@ -275,8 +287,9 @@ QString MainWindow::inputDockName()
     bool ok = false;
     QString text = QInputDialog::getText(nullptr, tr("Dock name"), tr("Enter the name to show in the Menu:"),
                                          QLineEdit::Normal, QString(), &ok);
-    if (ok && !text.isEmpty())
+    if (ok && !text.isEmpty()) {
         return text;
+    }
     return {};
 }
 
@@ -284,8 +297,9 @@ void MainWindow::allItemsChanged()
 {
     changed = true;
     for (int i = 0; i < apps.size(); ++i) {
-        if (index == i) // skip current element since we apply its style to all
+        if (index == i) { // skip current element since we apply its style to all
             continue;
+        }
         const QStringList app_info = QStringList(
             {apps.at(i).at(Info::App), apps.at(i).at(Info::Command), apps.at(i).at(Info::Icon),
              ui->comboSize->currentText(), ui->widgetBackground->palette().color(QWidget::backgroundRole()).name(),
@@ -321,27 +335,30 @@ void MainWindow::itemChanged()
     checkDoneEditing();
     displayIcon(ui->buttonSelectApp->text(), index);
     list_icons.at(index)->setStyleSheet(list_icons.at(index)->styleSheet() + "border-width: 10px;");
-    if (ui->checkApplyStyleToAll->isChecked())
+    if (ui->checkApplyStyleToAll->isChecked()) {
         allItemsChanged();
+    }
 }
 
 void MainWindow::mousePressEvent(QMouseEvent *event)
 {
-    if (this->childAt(event->pos()) == ui->widgetBackground)
-        pickColor(ui->widgetBackground);
-    else if (this->childAt(event->pos()) == ui->widgetHoverBackground)
-        pickColor(ui->widgetHoverBackground);
-    else if (this->childAt(event->pos()) == ui->widgetBorder)
-        pickColor(ui->widgetBorder);
-    else if (this->childAt(event->pos()) == ui->widgetHoverBorder)
-        pickColor(ui->widgetHoverBorder);
-    if (!checkDoneEditing())
+    auto *clickedWidget = this->childAt(event->pos());
+
+    if (clickedWidget == ui->widgetBackground || clickedWidget == ui->widgetHoverBackground
+        || clickedWidget == ui->widgetBorder || clickedWidget == ui->widgetHoverBorder) {
+        pickColor(clickedWidget);
+    }
+
+    if (!checkDoneEditing()) {
         return;
+    }
+
     if (event->button() == Qt::LeftButton) {
-        int i = ui->icons->layout()->indexOf(this->childAt(event->pos()));
+        int i = ui->icons->layout()->indexOf(clickedWidget);
         int old_idx = index;
-        if (i >= 0)
+        if (i >= 0) {
             showApp(index = i, old_idx);
+        }
     }
 }
 
@@ -366,23 +383,36 @@ void MainWindow::addDockToMenu(const QString &file_name)
 
 void MainWindow::deleteDock()
 {
-    this->hide();
-    const QString selected
+    hide();
+
+    const QString selectedDock
         = QFileDialog::getOpenFileName(nullptr, tr("Select dock to delete"), QDir::homePath() + "/.fluxbox/scripts",
                                        tr("Dock Files (*.mxdk);;All Files (*.*)"));
-    if (!selected.isEmpty()
-        && QMessageBox::question(nullptr, tr("Confirmation"), tr("Are you sure you want to delete %1?").arg(selected),
-                                 tr("&Delete"), tr("&Cancel"))
-               == 0) {
-        QFile::remove(selected);
-        cmd.run("sed -ni '\\|" + selected + "|!p' " + QDir::homePath() + "/.fluxbox/submenus/appearance", true);
-        cmd.run(QStringLiteral("pkill wmalauncher"), true);
+
+    if (!selectedDock.isEmpty()) {
+        const QMessageBox::StandardButton confirmation = QMessageBox::question(
+            nullptr, tr("Confirmation"), tr("Are you sure you want to delete %1?").arg(selectedDock),
+            QMessageBox::Yes | QMessageBox::Cancel);
+
+        if (confirmation == QMessageBox::Yes) {
+            if (QFile::remove(selectedDock)) {
+                cmd.run("sed -ni '\\|" + selectedDock + "|!p' " + QDir::homePath() + "/.fluxbox/submenus/appearance",
+                        true);
+                cmd.run(QStringLiteral("pkill wmalauncher"), true);
+            } else {
+                QMessageBox::warning(nullptr, tr("Error"), tr("Failed to delete the selected dock."));
+            }
+        }
     }
-    this->show();
+
+    show();
 }
 
 // block/unblock all relevant signals when loading stuff into GUI
-void MainWindow::blockComboSignals(bool block) { ui->comboSize->blockSignals(block); }
+void MainWindow::blockComboSignals(bool block)
+{
+    ui->comboSize->blockSignals(block);
+}
 
 void MainWindow::moveDock()
 {
@@ -413,8 +443,9 @@ void MainWindow::moveDock()
     // find location
     QRegularExpression re(possible_locations.join(QStringLiteral("|")));
     QRegularExpressionMatch match = re.match(text);
-    if (match.hasMatch())
+    if (match.hasMatch()) {
         slit_location = match.captured();
+    }
 
     // select location
     slit_location = pickSlitLocation();
@@ -456,25 +487,35 @@ void MainWindow::moveDock()
     this->show();
 }
 
-// move icon: pos -1 one to left, +1 one to right
+// Move icon: pos -1 to shift left, +1 to shift right
 void MainWindow::moveIcon(int pos)
 {
-    changed = true;
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    // swap instead of swapItemAt and don't use Qt::ReturnByValue for pixmap to make it work in Buster
-    apps.swap(index, index + pos);
-    QPixmap map = *list_icons.at(index)->pixmap();
-    list_icons.at(index)->setPixmap(*list_icons.at(index + pos)->pixmap());
-#else
-    apps.swapItemsAt(index, index + pos);
-    QPixmap map = list_icons.at(index)->pixmap(Qt::ReturnByValue);
-    list_icons.at(index)->setPixmap(list_icons.at(index + pos)->pixmap(Qt::ReturnByValue));
-#endif
-    list_icons.at(index + pos)->setPixmap(map);
-    list_icons.at(index)->setStyleSheet(list_icons.at(index + pos)->styleSheet());
+    int newIndex = index + pos;
+    if (newIndex < 0 || newIndex >= apps.size()) {
+        return;
+    }
 
-    index += pos;
-    showApp(index, index - 1);
+    changed = true;
+    // Swap the applications in the list
+    apps.swapItemsAt(index, newIndex);
+
+    // Swap the icons visually
+    QLabel *currentIconLabel = list_icons.at(index);
+    QLabel *newIconLabel = list_icons.at(newIndex);
+    QPixmap currentIcon = currentIconLabel->pixmap(Qt::ReturnByValue);
+    currentIconLabel->setPixmap(newIconLabel->pixmap(Qt::ReturnByValue));
+    newIconLabel->setPixmap(currentIcon);
+
+    // Update styles for the swapped icons
+    QString currentStyle = currentIconLabel->styleSheet();
+    currentIconLabel->setStyleSheet(newIconLabel->styleSheet());
+    newIconLabel->setStyleSheet(currentStyle);
+
+    // Update the current index
+    index = newIndex;
+
+    // Refresh the displayed application and highlight the current icon
+    showApp(index, index - pos);
     displayIcon(ui->buttonSelectApp->text(), index);
     list_icons.at(index)->setStyleSheet(list_icons.at(index)->styleSheet() + "border-width: 10px;");
 
@@ -513,18 +554,20 @@ void MainWindow::parseFile(QFile &file)
             options = line.split(QRegularExpression(QStringLiteral(" --| -")));
             options.removeAll(QString());
 
-            for (const QString &option : qAsConst(options)) {
+            for (const QString &option : std::as_const(options)) {
                 QStringList tokens = option.split(QStringLiteral(" "));
                 if (tokens.at(0) == QLatin1String("d") || tokens.at(0) == QLatin1String("desktop-file")) {
                     ui->radioDesktop->setChecked(true);
-                    if (tokens.size() > 1)
+                    if (tokens.size() > 1) {
                         ui->buttonSelectApp->setText(tokens.at(1));
+                    }
                     ui->buttonSelectIcon->setToolTip(QString());
                     ui->buttonSelectIcon->setStyleSheet(QStringLiteral("text-align: center; padding: 3px;"));
                 } else if (tokens.at(0) == QLatin1String("c") || tokens.at(0) == QLatin1String("command")) {
                     ui->radioCommand->setChecked(true);
-                    if (tokens.size() > 1)
+                    if (tokens.size() > 1) {
                         ui->lineEditCommand->setText(tokens.mid(1).join(QStringLiteral(" ")).trimmed());
+                    }
                     ui->buttonSelectIcon->setStyleSheet(QStringLiteral("text-align: right; padding: 3px;"));
                 } else if (tokens.at(0) == QLatin1String("i") || tokens.at(0) == QLatin1String("icon")) {
                     if (tokens.size() > 1) {
@@ -557,8 +600,9 @@ void MainWindow::parseFile(QFile &file)
                         setColor(ui->widgetHoverBorder, color);
                     }
                 } else if (tokens.at(0) == QLatin1String("w") || tokens.at(0) == QLatin1String("window-size")) {
-                    if (tokens.size() > 1)
+                    if (tokens.size() > 1) {
                         ui->comboSize->setCurrentIndex(ui->comboSize->findText(tokens.at(1) + "x" + tokens.at(1)));
+                    }
                 } else if (tokens.at(0) == QLatin1String("x") || tokens.at(0) == QLatin1String("exit-on-right-click")) {
                     // not used right now
                 } else { // other not handled options, add them as a propriety to the app button
@@ -585,8 +629,9 @@ void MainWindow::buttonSave_clicked()
     slit_location = pickSlitLocation();
 
     // create "~/.fluxbox/scripts" if it doesn't exist
-    if (!QFileInfo::exists(QDir::homePath() + "/.fluxbox/scripts"))
+    if (!QFileInfo::exists(QDir::homePath() + "/.fluxbox/scripts")) {
         QDir().mkpath(QDir::homePath() + "/.fluxbox/scripts");
+    }
 
     bool new_file = false;
     if (!QFileInfo::exists(file_name)
@@ -594,10 +639,12 @@ void MainWindow::buttonSave_clicked()
                == QMessageBox::question(this, tr("Overwrite?"), tr("Do you want to overwrite the dock file?"))) {
         file_name = QFileDialog::getSaveFileName(this, tr("Save file"), QDir::homePath() + "/.fluxbox/scripts",
                                                  tr("Dock Files (*.mxdk);;All Files (*.*)"));
-        if (file_name.isEmpty())
+        if (file_name.isEmpty()) {
             return;
-        if (!file_name.endsWith(QLatin1String(".mxdk")))
+        }
+        if (!file_name.endsWith(QLatin1String(".mxdk"))) {
             file_name += QLatin1String(".mxdk");
+        }
         new_file = true;
     }
     QFile file(file_name);
@@ -638,7 +685,7 @@ void MainWindow::buttonSave_clicked()
             out << file_content.replace(re, new_line);
         }
     }
-    for (const auto &app : qAsConst(apps)) {
+    for (const auto &app : std::as_const(apps)) {
         QString command = (app.at(Info::App).endsWith(QLatin1String(".desktop")))
                               ? "--desktop-file " + app.at(Info::App)
                               : "--command " + app.at(Info::Command) + " --icon " + app.at(Info::Icon);
@@ -651,14 +698,17 @@ void MainWindow::buttonSave_clicked()
     file.close();
     QFile::setPermissions(file_name, QFlag(0x744));
 
-    if (dock_name.isEmpty() || new_file)
+    if (dock_name.isEmpty() || new_file) {
         dock_name = inputDockName();
+    }
 
-    if (dock_name.isEmpty())
+    if (dock_name.isEmpty()) {
         dock_name = QFileInfo(file).baseName();
+    }
 
-    if (!isDockInMenu(file.fileName()))
+    if (!isDockInMenu(file.fileName())) {
         addDockToMenu(file.fileName());
+    }
 
     QMessageBox::information(this, tr("Dock saved"),
                              tr("The dock has been saved.\n\n"
@@ -697,11 +747,20 @@ void MainWindow::buttonHelp_clicked()
     displayDoc(url, tr("%1 Help").arg(this->windowTitle()));
 }
 
-void MainWindow::comboSize_currentTextChanged() { itemChanged(); }
+void MainWindow::comboSize_currentTextChanged()
+{
+    itemChanged();
+}
 
-void MainWindow::comboBgColor_currentTextChanged() { itemChanged(); }
+void MainWindow::comboBgColor_currentTextChanged()
+{
+    itemChanged();
+}
 
-void MainWindow::comboBorderColor_currentTextChanged() { itemChanged(); }
+void MainWindow::comboBorderColor_currentTextChanged()
+{
+    itemChanged();
+}
 
 void MainWindow::buttonNext_clicked()
 {
@@ -772,7 +831,12 @@ void MainWindow::setConnections()
     connect(ui->buttonSave, &QPushButton::clicked, this, &MainWindow::buttonSave_clicked);
     connect(ui->buttonSelectApp, &QPushButton::clicked, this, &MainWindow::buttonSelectApp_clicked);
     connect(ui->buttonSelectIcon, &QPushButton::clicked, this, &MainWindow::buttonSelectIcon_clicked);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    connect(ui->checkApplyStyleToAll, &QCheckBox::checkStateChanged, this,
+            &MainWindow::checkApplyStyleToAll_stateChanged);
+#else
     connect(ui->checkApplyStyleToAll, &QCheckBox::stateChanged, this, &MainWindow::checkApplyStyleToAll_stateChanged);
+#endif
     connect(ui->comboSize, &QComboBox::currentTextChanged, this, &MainWindow::comboSize_currentTextChanged);
     connect(ui->lineEditCommand, &QLineEdit::textEdited, this, &MainWindow::lineEditCommand_textEdited);
     connect(ui->radioDesktop, &QRadioButton::toggled, this, &MainWindow::radioDesktop_toggled);
@@ -828,8 +892,9 @@ void MainWindow::showApp(int idx, int old_idx)
     ui->buttonMoveLeft->setDisabled(idx == 0);
     ui->buttonMoveRight->setDisabled(idx == apps.size() - 1);
 
-    if (old_idx != -1)
+    if (old_idx != -1) {
         list_icons.at(old_idx)->setStyleSheet(list_icons.at(old_idx)->styleSheet() + "border-width: 4px;");
+    }
     list_icons.at(idx)->setStyleSheet(list_icons.at(idx)->styleSheet() + "border-width: 10px;");
 }
 
@@ -853,12 +918,13 @@ void MainWindow::editDock(const QString &file_arg)
     this->hide();
 
     QString selected_dock;
-    if (!file_arg.isEmpty() && QFile::exists(file_arg))
+    if (!file_arg.isEmpty() && QFile::exists(file_arg)) {
         selected_dock = file_arg;
-    else
+    } else {
         selected_dock
             = QFileDialog::getOpenFileName(nullptr, tr("Select a dock file"), QDir::homePath() + "/.fluxbox/scripts",
                                            tr("Dock Files (*.mxdk);;All Files (*.*)"));
+    }
 
     if (!QFileInfo::exists(selected_dock)) {
         QMessageBox::warning(nullptr, tr("No file selected"),
@@ -915,8 +981,9 @@ void MainWindow::radioDesktop_toggled(bool checked)
     } else {
         ui->buttonSelectApp->setText(tr("Select..."));
     }
-    if (!parsing)
+    if (!parsing) {
         checkDoneEditing();
+    }
 }
 
 void MainWindow::pickColor(QWidget *widget)
@@ -925,10 +992,11 @@ void MainWindow::pickColor(QWidget *widget)
     if (color.isValid()) {
         setColor(widget, color);
         itemChanged();
-        if (widget == ui->widgetBackground)
+        if (widget == ui->widgetBackground) {
             setColor(ui->widgetHoverBackground, "black");
-        else if (widget == ui->widgetBorder)
+        } else if (widget == ui->widgetBorder) {
             setColor(ui->widgetHoverBorder, "white");
+        }
     }
 }
 
@@ -963,8 +1031,9 @@ void MainWindow::buttonSelectIcon_clicked()
         displayIcon(ui->buttonSelectIcon->text(), index);
         list_icons.at(index)->setStyleSheet(list_icons.at(index)->styleSheet() + "border-width: 10px;");
     }
-    if (!parsing)
+    if (!parsing) {
         checkDoneEditing();
+    }
 }
 
 void MainWindow::lineEditCommand_textEdited()
@@ -978,8 +1047,9 @@ void MainWindow::lineEditCommand_textEdited()
         ui->buttonNext->setEnabled(false);
         return;
     }
-    if (!parsing)
+    if (!parsing) {
         checkDoneEditing();
+    }
 }
 
 void MainWindow::buttonAdd_clicked()
@@ -1004,20 +1074,23 @@ void MainWindow::buttonAdd_clicked()
 
 void MainWindow::buttonMoveLeft_clicked()
 {
-    if (index == 0)
+    if (index == 0) {
         return;
+    }
     moveIcon(-1);
 }
 
 void MainWindow::buttonMoveRight_clicked()
 {
-    if (index == apps.size() - 1)
+    if (index == apps.size() - 1) {
         return;
+    }
     moveIcon(1);
 }
 
 void MainWindow::checkApplyStyleToAll_stateChanged(int arg1)
 {
-    if (arg1 == Qt::Checked)
+    if (arg1 == Qt::Checked) {
         allItemsChanged();
+    }
 }
